<?php

// If this file is called directly, abort.
if (!defined('WPINC')) {
    wp_die();
}

class SDOP_Admin
{

    /**
     * Instance of this class.
     *
     * @since    1.0.0
     *
     * @var      object
     */
    protected static $instance = null;

    /**
     * Constructor
     *
     * @since     1.0.0
     */

    public function __construct()
    {
        // Add styles
        if (SDOP_Admin::check_admin()) {
            add_action('admin_enqueue_scripts', [$this, 'enqueue_admin_styles']);
            add_action('admin_enqueue_scripts', [$this, 'enqueue_admin_scripts']);
        }
        add_action('admin_menu', [$this, 'add_menu_page']);
    }

    /**
     * Return an instance of this class.
     *
     * @return    object    A single instance of this class.
     * @since     1.0.0
     *
     */
    public static function get_instance()
    {
        // If the single instance hasn't been set, set it now.
        if (null == self::$instance) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    /**
     *
     */
    public function enqueue_admin_styles()
    {

        wp_enqueue_style(SEZNAM_SDOP_SLUG . '-admin-styles', SEZNAM_SDOP_URL .'assets/css/admin.min.css', [], SEZNAM_SDOP_VERSION);

        //Enqueue the jQuery UI theme css file from google:
        $wp_scripts = wp_scripts();

        wp_enqueue_style(
            'jquery-ui-theme-smoothness', //select ui theme: base...
            sprintf(
                'https://ajax.googleapis.com/ajax/libs/jqueryui/%s/themes/smoothness/jquery-ui.css',
                $wp_scripts->registered['jquery-ui-core']->ver
            )
        );

    }

    /**
     * Register and enqueue admin-specific JavaScript.
     *
     * @return    null    Return early if no settings page is registered.
     * @since     1.0.0
     *
     */
    public function enqueue_admin_scripts()
    {
        wp_enqueue_script(SEZNAM_SDOP_SLUG . '-admin-js', SEZNAM_SDOP_URL . 'assets/js/szn-sdop.js', ['jquery'], SEZNAM_SDOP_VERSION);

        wp_enqueue_script('jquery-ui-core', false, ['jquery']);
        wp_enqueue_script("jquery-ui-tabs");

    }

    /**
     *
     */
    public function add_menu_page()
    {

        if (current_user_can(SEZNAM_SDOP_CAPABILITY)):
            if(class_exists('SSSP_Admin')){
                add_submenu_page(
                    SEZNAM_SSP_SLUG,
                    esc_attr__('Seznam Recommender', SEZNAM_SDOP_SLUG),
                    esc_attr__('Seznam Recommender', SEZNAM_SDOP_SLUG),
                    SEZNAM_SDOP_CAPABILITY,
                    'seznam-sdop-admin',
                    [$this, 'sdop_settings']
                );
            }

            add_submenu_page(
                'tools.php',
                esc_attr__('Seznam Recommender', SEZNAM_SDOP_SLUG),
                esc_attr__('Seznam Recommender', SEZNAM_SDOP_SLUG),
                SEZNAM_SDOP_CAPABILITY,
                'seznam-sdop-admin',
                [$this, 'sdop_settings']
            );

            add_submenu_page(
                null,
                esc_attr__('Seznam recomm. box', SEZNAM_SDOP_SLUG),
                esc_attr__('Seznam recomm. box', SEZNAM_SDOP_SLUG),
                SEZNAM_SDOP_CAPABILITY,
                'seznam-sdop-admin-rss',
                [$this, 'sdop_settings_rss']
            );



        endif;
    }

    /**
     * @return bool
     */
    public static function check_admin()
    {

        if (isset($_GET['page']) && $_GET['page'] == 'seznam-sdop-admin') {
            return true;
        }
        if (isset($_GET['page']) && $_GET['page'] == 'seznam-sdop-admin-rss') {
            return true;
        }
        if (isset($_POST['sdop-admin-save'])) {
            return true;
        }

        return false;
    }

    /**
     *
     */
    public function sdop_settings()
    {
        if(isset($_GET['page']) && $_GET['page'] == 'seznam-sdop-admin'){
            require_once(SEZNAM_SDOP_PATH . 'includes/sdop_settings_page.php');
            echo SDOP_SettingsPage::display_admin_page();
        }

    }

    /**
     *
     */
    public function sdop_settings_rss()
    {
        if(isset($_GET['page']) && $_GET['page'] == 'seznam-sdop-admin-rss'){
            require_once(SEZNAM_SDOP_PATH . 'includes/sdop_settings_page.php');
            echo SDOP_SettingsPage::display_admin_page_rss();
        }

    }

}